@@ -1,4 +1,4 @@
-from Asset import Asset
+from RBX_py.Asset import Asset
 
 class Client:
     def __init__(self):
@@ -14,8 +14,4 @@ class Client:
 
         asset_obj = Asset(id=id)
         asset_obj.fetchData()
-        return asset_obj
-
-c = Client()
-e = c.FetchAsset(456225312)
-print(e.Name)
\ No newline at end of file
+        return asset_obj
\ No newline at end of file
